pub enum Instruction {
AInstruction(String),
CInstruction(String, String, String),
}Expand description
Enum to represent the different types of instructions in the Hack Assembly Language. Contains variants for A-Instructions and C-Instructions. Each variant contains the necessary data to represent the instruction.
Variants
AInstruction(String)
A-Instruction variant, contains the address or symbol of the instruction.
CInstruction(String, String, String)
C-Instruction variant, contains the destination, computation, and jump mnemonics, respectively.