Structs
- Assembler
- Struct to represent the Assembler’s internal logic.
Contains the file references, symbol table, and other necessary state.
Can be constructed using the
buildfunction.
Enums
- Instruction
- Enum to represent the different types of instructions in the Hack Assembly Language. Contains variants for A-Instructions and C-Instructions. Each variant contains the necessary data to represent the instruction.